import argparse
from typing import List
from typing import Union

from fzflib import FZF


def main() -> int:

    # CLI
    parser = argparse.ArgumentParser()

    parser.add_argument(
        "--multi",
        action="store_true",  # Default: False
        help="Mutliple selections. Default: False",
    )

    args = parser.parse_args()

    # Options
    multi: bool = args.multi

    # Logic

    fzf = FZF(multi=multi)

    result: Union[str, List[str]] = fzf.prompt()

    print(result)

    return 0


if __name__ == '__main__':
    raise SystemExit(main())



import logging.config
import os
from pathlib import Path


logs_path: Path = Path(__file__).parent / 'logs'
logs_path.mkdir(exist_ok=True)
log_file: Path = logs_path / Path(__file__).with_suffix('.log').name


logging_config: dict = dict(
    version=1,
    disable_existing_loggers=False,
    root=dict(
        level=logging.DEBUG,
        handlers=['file_handler'],
    ),
    formatters={
        'default': {
            'date_format': '%Y-%m-%dT%H:%M:%S+0000%z',
            'format': '{asctime} - {name} - {levelname:<8} - {message}',
            'style': '{',
            'validate': True,
        }
    },
    handlers={
        'file_handler': {
            'level': logging.DEBUG,
            'class': 'logging.FileHandler',
            'formatter': 'default',
            'filename': log_file,
        }
    },
    loggers={},
)


def get_logger(options: dict = None) -> "Logger":
    """Get logger."""

    # Default Options
    if options is None:
        options = dict(
            name='root',
        )

    # Get Logger
    name: str = options['name']
    logger = logging.getLogger(name)

    # Global Helpers
    date_format = '%Y-%m-%dT%H:%M:%S%z'
    message_format = '{asctime} - {name} - {levelname:<8} - {message}'
    formatter = logging.Formatter(
        datefmt=date_format,
        style='{',
        fmt=message_format,
    )

    # Debug
    if os.environ.get('FZFLIB_DEBUG') is not None:
        stream_handler = logging.StreamHandler()
        stream_handler.setLevel(logging.DEBUG)
        stream_handler.setFormatter(formatter)

        logger.addHandler(stream_handler)

    return logger



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
import setuptools


with open('README.md', 'r', encoding='utf-8') as fin:
    long_description = fin.read()


setuptools.setup(
    name='fzflib',
    version='0.1.15',
    license='MIT',
    author='Kyle L. Davis',
    author_email='AceofSpades5757.github@gmail.com',
    url='https://github.com/AceofSpades5757/fzflib',
    project_urls={
        'Documentation': 'https://fzflib.readthedocs.io/en/latest/',
        'Author': 'https://github.com/AceofSpades5757',
    },
    description='A Python library for interacting with FZF.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    python_requires='>=3.6',
    packages=setuptools.find_packages('src'),
    package_dir={'': 'src', 'fzflib': 'src/fzflib'},
    test_suite="tests",
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        "Development Status :: 2 - Pre-Alpha",
        "Operating System :: OS Independent",
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
    ],
)
